Class: Decidim::Api::DocumentationController

Inherits:
Api::ApplicationController
  • Object
show all
Defined in:
app/controllers/decidim/api/documentation_controller.rb

Overview

This controller takes queries from an HTTP endpoint and sends them out to the Schema to be executed, later returning the response as JSON.