Module: Decidim::Api::UserExtension

Extended by:
ActiveSupport::Concern
Defined in:
app/models/concerns/decidim/api/user_extension.rb

Overview

This concern adds the JWT authenticable strategy for the User models to allow regular users to sign in through the API (if configured from the system panel). Allows normal users to utilize the API e.g. through mobile applications.